@@ -12,7 +12,7 @@ use Scalar::Util qw(blessed);
 
 use base 'Date::Holidays::Adapter';
 
-$VERSION = '1.04';
+$VERSION = '1.05';
 
 sub new {
     my ( $class, %params ) = @_;
@@ -275,7 +275,7 @@ Date::Holidays - Date::Holidays::* adapter and aggregator for all your holiday n
 
 =head1 VERSION
 
-This POD describes version 1.04 of Date::Holidays
+This POD describes version 1.05 of Date::Holidays
 
 =head1 FEATURES
 
@@ -816,6 +816,9 @@ Test coverage in version 1.02
 
 =over
 
+=item * CHORNY (Alexandr Ciornii), Github issue #10, letting me know I included local/ by accident,
+resulting in release 1.05
+
 =item * Vladimir Varlamov, PR introducing Date::Holidays::BY resulting in 1.04
 
 =item * Joseph M. Orost, bug report resulting in 1.03
